<?php

/**
 * Run
 *
 * @package FileIndexingTool
 *
 * @author Tomasz Świenty
 * @version 3.4
 * @copyright Copyright (c) eDokumenty
 */

$options = getopt('h:');
$host = '';
if (is_array($options) AND $options) {
    $host = isset($options['h']) ? $options['h'] : '';

    if ($host) {
        $_SERVER['HTTP_HOST'] = $host.'.';
    }
}

chdir(dirname(__FILE__).'/../../');

/* ------------------------------- CONFIG ------------------------------- */
// ścieżka do katalogu z tym narzędziem jeśli umieścić gdzieś głębiej niż scripts wtedy zmień tu
$TOOL_PATH = dirname(__FILE__);

// Jaki pliki ma indeksować np. po rozszerzeniach
// FILTROWANIE NASTĘPUJE PO KOLUMNIE files.filenm
// przykład $filterPatterns = ['.pdf$', '.rtf$'];
$filterPatterns = [];

// Główna kwerenda wyciągająca pliki do zaindeksowanie
// domyślnie pobiera wszystkie
$query = 'SELECT fileid, filenm FROM files WHERE fileid >= 1';

// Dodatkowe filtry
// filtr można predefiniowac wszystko bedzie łączone z AND
// przykład $filter = array('filenm = \'tata\'', 'fileid = 66');
$filter = [];

if ($filter) {
    $query .= ' AND ('.implode(' AND ', $filter).')';
}

// filter string using filter pattern
if ($filterPatterns) {
    $filter = [];
    $filterPatterns = array_filter($filterPatterns);
    foreach ($filterPatterns as $filterPattern) {
        $filter[] = 'filenm ~* E\''.$filterPattern.'\'';
    }

    $filter = array_filter($filter);
    if ($filter) {
        $query .= ' AND ('.implode(' OR ', $filter).')';
    }
}

echo 'Twoje zapytanie: '.$query."\n";

/* ------------------------------- CONFIG ------------------------------- */

date_default_timezone_set('Europe/Warsaw');
set_time_limit(0);
ini_set('memory_limit', -1);

require_once('./../../framework/lib/util/Translator/Translator.inc');

define('SCRIPT_PATH', '.');
define('ASYNC_SERVICE', FALSE);
require_once('./config.inc');
require_once('../../framework/globalVar.inc');
include_once(LIB_PATH.'system/SysContext.inc');
require_once('./localVar.inc');
require_once(FUNC_PATH.'GetUsrAcc.inc');
require_once(LIB_PATH.'system.inc');
require_once(LIB_PATH.'db/PgManager.inc');
require_once(LIB_PATH.'util/Debug.inc');
require_once(LIB_PATH.'util/Strings.inc');
require_once(LIB_PATH.'db/Bean.inc');
require_once(LIB_PATH.'system/LoggedUser.inc');
require_once(LIB_PATH.'system/VarPathService.inc');
require_once('./classes/DataSources/DataSourceManager.inc');
require_once('./classes/FeatureBox/FeaturesHelper.inc');
require_once('./classes/Log/File/FileLog.inc');

SysContext::$usr_info = array(
        'usr_id' => 1,
        'orunid' => '',
        'lasnam' => Translator::translate('CronRunner'),
        'firnam' => 'Cron',
        'usrnam' => 'CronRunner'
        );

final class FileIndexLog {


    private $log = FALSE;


    public function __construct() {

        $this->log = new FileLog(Log::FILE_LOG_WRITER);

    }


    public function write($message, $priority = Log::EVENT_INFO) {

        $this->log->setWriterConfig(Log::FILE_LOG_WRITER, array('clsnam' => 'FILE_INDEX'));
        $this->log->write($message, Log::getDayKey(), FALSE, FALSE, $priority);

    }

}

$log = new FileIndexLog();
$log->write(sprintf('Odpalam FileIndexingTool::Run%s', ($host ? ' dla '.$host : '')));
$log->write(sprintf('Wykonuję zapytanie: %s', $query));

$db = new PgManager(DB_NAME);
$files = $db->query($query, FALSE, PGSQL_ASSOC);

if (!isset($files[0]['fileid'])) {
    $log->write(sprintf('Brak plików spełniających zapytanie: %s', $query));
    exit();
}

$c = count($files);

$log->write(sprintf('Znaleziono plików: %s', $c));
$log->write('Trwa indeksowania ...');

foreach ($files as $i => $file) {
    $cc = ++$i;
    $log->write(sprintf('Indeksowanie pliku (%s/%s): %s', $cc, $c, $file['fileid'].'_'.$file['filenm']));

    $start = microtime(TRUE);
    $previewFile = '';
    passthru('php '.$TOOL_PATH.'/FileIndex.inc '.$file['fileid'].' '.$host, $previewFile);
    $end = microtime(TRUE);

    $log->write(sprintf('Koniec indeksowania pliku (%s/%s): %s. Czas: %s', $cc, $c, $file['fileid'].'_'.$file['filenm'], ($end - $start).' sek'));
}

$db->commit();