#!/usr/bin/env python
import signal
import string
import sys
import datetime
import argparse
from itertools import chain

import pika
import json

if (sys.version_info > (3, 0)):
    import configparser
else:
    import ConfigParser

    reload(sys)
    sys.setdefaultencoding('utf8')

import smtplib
import logging
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from email.utils import formatdate

logging.basicConfig(filename='logs/sendmail-' + datetime.datetime.today().strftime('%Y-%m-%d_%H-%M-%S') + '.log',
                    level=logging.INFO)

parser = argparse.ArgumentParser()
parser.add_argument('-c', '--config', help='use custom config file (edokumenty.ini is default)')


def printLog(text):
    # 'Print string to standard output'
    print(datetime.datetime.today().strftime('%Y-%m-%d %H:%M:%S') + " " + text)
    logging.info(datetime.datetime.today().strftime('%Y-%m-%d %H:%M:%S') + " " + text)
    return


args = parser.parse_args()

if args.config is not None:
    configFile = args.config
else:
    configFile = "edokumenty.ini"

printLog("[ ] Loading config file " + configFile)

# Wczytanie konfiguracji
try:
    if (sys.version_info > (3, 0)):
        Config = configparser.ConfigParser()
    else:
        Config = ConfigParser.ConfigParser()

    Config.read(configFile)
    host = Config.get("SMTP", "host")
    port = Config.get("SMTP", "port")
    user = Config.get("SMTP", "user")
    password = Config.get("SMTP", "password")

    # konfiguracja polaczenia z RabbitMQ
    pikaHost = Config.get("RabitMQ", "host")
    pikaVHost = Config.get("RabitMQ", "vhost")
    pikaPort = Config.get("RabitMQ", "port")
    pikaCredentials = pika.PlainCredentials(Config.get("RabitMQ", "user"), Config.get("RabitMQ", "password"))
except Exception as e:
    printLog("[x] Incorrect config file - check " + configFile + ": " + str(e))
    sys.exit()

try:
    fromaddr = Config.get("SMTP", "from")
except:
    fromaddr = user

try:
    bcc = Config.get("SMTP", "bcc")
except:
    bcc = ''

try:
    tls = Config.get("SMTP", "tls") in ['true', 'True', '1', 'y', 'yes', 'on']
except:
    printLog('ERROR')
    tls = False

printLog("[" + u"\u2713" + "] Config loaded")

connection = pika.BlockingConnection(pika.ConnectionParameters(pikaHost, pikaPort, pikaVHost, pikaCredentials))
channel = connection.channel()
channel.queue_declare(queue='sendEmailCommand',
                      durable=True)


def callback(ch, method, properties, body):
    printLog("[" + u"\u2713" + "] Received email to send")
    try:
        decoded = json.loads(body)

        msg = MIMEMultipart('alternative')
        msg['Subject'] = decoded['headers']['Subject']
        msg['To'] = decoded['headers']['To']
        msg['From'] = fromaddr
        msg['Date'] = formatdate(localtime=True)
        msg.attach(MIMEText(decoded['body'].encode('utf-8'), 'html', 'utf-8'))
        server = smtplib.SMTP(host, port)
        if tls:
            server.starttls()

        server.login(user, password)

        cc = ''

        msg['Cc'] = cc
        msg['Bcc'] = bcc

        server.sendmail(user, [msg['To']] + [cc] + [bcc], msg.as_string())
        server.quit()

        ch.basic_ack(delivery_tag=method.delivery_tag)
        printLog("[" + u"\u2713" + "] Message sent to " + msg['To'])

    except Exception as e:
        ch.basic_ack(delivery_tag=method.delivery_tag)
        printLog("[x] Invalid data: " + str(e))


channel.basic_qos(prefetch_count=1)
channel.basic_consume(on_message_callback=callback, queue='sendEmailCommand')

printLog('[*] Waiting for messages. To exit press CTRL+C')
try:
    channel.start_consuming()
except KeyboardInterrupt:
    printLog("[*] interrupt received, stopping...")
finally:
    # clean up
    channel.close()
    sys.exit(0)
